# rasqc
Automated QA/QC checks on HEC-RAS models.

## Developer Setup
```
$ python -m venv venv-rasqc
```
```
$ source ./venv-rasqc/bin/activate
```
```
(venv-rasqc) $ pip install ".[dev]"
```
To run:
```
(venv-rasqc) $ python -m rasqc.main --help
```